@@ -7,6 +7,7 @@ from tomoe.simplyh import get_sim
 from tomoe.hentaifox import get_hfox
 from tomoe.hentai2read import get_h2r
 from tomoe.asmhentai import get_asm
+from tomoe.threehentai import get_three
 from tomoe.bulk_download import get_bulk
 from tomoe.utils.misc import choose, need_args
 
@@ -20,6 +21,7 @@ class Tomoe:
         Haentaifox: str = choose().hentaifox,
         Hentai2read: str = choose().hentai2read,
         Asmhentai: str = choose().asmhentai,
+        Threehentai: str = choose().three,
         Bulk: str = choose().bulk,
     ):
 
@@ -29,6 +31,7 @@ class Tomoe:
         self.hentaifox = Haentaifox
         self.hentai2read = Hentai2read
         self.asmhentai = Asmhentai
+        self.threehentai = Threehentai
         self.bulk = Bulk
 
 
@@ -54,6 +57,9 @@ def main():
     async def main_asmhentai():
         await asyncio.gather(get_asm(Api.asmhentai))
 
+    async def main_threehentai():
+        await asyncio.gather(get_three(Api.threehentai))
+
     async def main_bulk():
         await asyncio.gather(get_bulk(Api.bulk))
 
@@ -75,6 +81,9 @@ def main():
     elif Api.asmhentai is not None:
         asyncio.run(main_asmhentai())
 
+    elif Api.threehentai is not None:
+        asyncio.run(main_threehentai())
+
     elif Api.bulk is not None:
         asyncio.run(main_bulk())
 
